aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/captcha/captcha_non_gd.php
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/includes/captcha/captcha_non_gd.php')
-rw-r--r--phpBB/includes/captcha/captcha_non_gd.php7
1 files changed, 3 insertions, 4 deletions
diff --git a/phpBB/includes/captcha/captcha_non_gd.php b/phpBB/includes/captcha/captcha_non_gd.php
index 41bd22868e..bb4e5af443 100644
--- a/phpBB/includes/captcha/captcha_non_gd.php
+++ b/phpBB/includes/captcha/captcha_non_gd.php
@@ -30,15 +30,14 @@ class captcha
}
/**
* Create the image containing $code
*/
- function execute($code)
+ function execute($code, $seed)
{
$img_height = $this->height - 10;
$img_width = 0;
- list($usec, $sec) = explode(' ', microtime());
- mt_srand($sec * $usec);
+ mt_srand($seed);
$char_widths = $hold_chars = array();
$code_len = strlen($code);
@@ -30,15 +30,14 @@ class captcha
}
/**
- * Create the image containing $code
+ * Create the image containing $code with a seed of $seed
*/